/*----------------------------------------------------------*/
/*    Copyright (C) Siemens AG (1999). All Rights Reserved	*/
/*    Product:          SIMATIC PDM							*/
/*                                                          */
/*    Device:           P&F LB/FB-REMOTE IO                 */
/*    Description:      PT100 Meumformer					*/
/*												            */
/*    Dictionary:       PFDP_DC_V6.dct                      */
/*                                                          */
/*  $Revision:   1.23  $                                    */
/*  $Date:   06 Apr 2000 12:47:46  $                        */
/*----------------------------------------------------------*/


#define		SENSOR_RTD_UNIT_C								\
			(TempR_P1_Option_Temperatur == 0)				\

#define		SENSOR_RTD_UNIT_F								\
			(TempR_P1_Option_Temperatur != 0)				\


#define		SENSOR_RTD_R									\
			(TempR_P1_Option_Sensortyp == 0x0000)			\

#define		SENSOR_RTD_TEMP									\
			(TempR_P1_Option_Sensortyp != 0x0000)			\


#define		TempR_MB_ME_MIN_VALUES							\
			IF (SENSOR_RTD_R)								\
				{											\
					0.000;									\
				}											\
			ELSE											\
			{												\
				IF (SENSOR_RTD_UNIT_C)						\
				{											\
					-200.000;								\
				}											\
				ELSE										\
				{											\
					-328.000;								\
				}											\
			}


#define		TempR_MB_ME_MAX_VALUES							\
			IF (SENSOR_RTD_R)								\
				{											\
					400.000;								\
				}											\
			ELSE											\
			{												\
				IF (SENSOR_RTD_UNIT_C)						\
				{											\
					850.000;								\
				}											\
				ELSE										\
				{											\
					1562.000;								\
				}											\
			}

/***********************************************************************/
/*    Unit relations                                                   */
/***********************************************************************/

UNIT TempR_TC_MB_ME_UNIT_RELATION	// Temperatur C
{							
	Loc_TempR_T_MbMe_Unit:	
								
	Loc_TempR_TC_P1_Mb,		
	Loc_TempR_TC_P1_Me
}

UNIT TempR_TF_MB_ME_UNIT_RELATION	// Temperatur F
{							
	Loc_TempR_T_MbMe_Unit:	
								
	Loc_TempR_TF_P1_Mb,		
	Loc_TempR_TF_P1_Me
}


UNIT TempR_R_MB_ME_UNIT_RELATION	// Widerstand
{							
	Loc_TempR_R_MbMe_Unit:
							
	Loc_TempR_R_P1_Mb,		
	Loc_TempR_R_P1_Me
}


VARIABLE Loc_TempR_T_MbMe_Unit
{
	LABEL		[unit];
	HELP		[unit_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 32;
		{32,  [degC]	},
		{33,  [degF]	}									
	}
	PRE_EDIT_ACTIONS
	{
		DEFINITION
		{
			if (TempR_P1_Option_Temperatur != 0)	
			{											
				Loc_TempR_T_MbMe_Unit = 33;		// [degF]
			}											
			else 
			{											
				Loc_TempR_T_MbMe_Unit = 32;		// [degC]
			}											
		}
	}
	POST_EDIT_ACTIONS
	{
		DEFINITION
		{
			if (Loc_TempR_T_MbMe_Unit != 32)	
			{											
				TempR_P1_Option_Temperatur = 1;	// [degF]
			}											
			else 
			{											
				TempR_P1_Option_Temperatur = 0;	// [degC]
			}											
		}
	}
	HANDLING	READ & WRITE;
}

VARIABLE Loc_TempR_R_MbMe_Unit
{
	LABEL		[unit];
	HELP		[unit_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 37;
		{37,  [Ohm]		}									
	}
	HANDLING	READ & WRITE;
}

/***********************************************************************/
/*    METHOD												           */
/***********************************************************************/

METHOD methode_set_TempR_MbMe
{
	CLASS			INPUT;
	DEFINITION
	{
		if (SENSOR_RTD_R)
		{
			Loc_TempR_R_P1_Mb	= Loc_TempR_R_P1_Mb.DEFAULT_VALUE;
			Loc_TempR_R_P1_Me	= Loc_TempR_R_P1_Me.DEFAULT_VALUE;
		}
		else	if (SENSOR_RTD_UNIT_C)
				{
					Loc_TempR_TC_P1_Mb	= Loc_TempR_TC_P1_Mb.DEFAULT_VALUE;
					Loc_TempR_TC_P1_Me	= Loc_TempR_TC_P1_Me.DEFAULT_VALUE;
				}
				else
				{
					Loc_TempR_TF_P1_Mb	= Loc_TempR_TF_P1_Mb.DEFAULT_VALUE;
					Loc_TempR_TF_P1_Me	= Loc_TempR_TF_P1_Me.DEFAULT_VALUE;
				}
	}
}

/*******************************************************************************/
/*****	Variables Kanal1 Index2	***************************************************/
/*******************************************************************************/

TempR_P1_Slot2	LIKE VARIABLE	P0_Slot0
{
}

TempR_P1_Index2	LIKE VARIABLE	P0_Index0
{
	REDEFINE TYPE	UNSIGNED_INTEGER
			{
				DEFAULT_VALUE 2;
			}
}

VARIABLE	TempR_P1_Mode
{
	LABEL		[P1_Mode_TempR];
	HELP		[P1_Mode_TempR_help];
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 2;
		{ 0,	[zwei_leiter]	}
		{ 1,	[drei_leiter]	}
		{ 2,	[vier_leiter]	}
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	TempR_P1_Option_Leitung
{
	LABEL		[P1_Option_Leitung];
	HELP		[P1_Option_Leitung_help];
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 1;
		{ 0,	[no]		},
		{ 1,	[yes]		}
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	TempR_P1_Option_Sensortyp
{
	LABEL		[P1_lin_type];
	HELP		[P1_lin_type_help];
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 1;
		{	0x0000,	[linear]	},
		{	0x0001,	[pt100]		}
	}
	CLASS		CONTAINED;
	POST_EDIT_ACTIONS
	{
		methode_set_TempR_MbMe
	}
	HANDLING	READ & WRITE;
}

VARIABLE	TempR_P1_Option_Temperatur
{
	LABEL		[unit];
	HELP		[unit_help];
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 0;	
		{0,  [degC]	},
		{1,  [degF]	}
	}
	CLASS		CONTAINED;
	PRE_EDIT_ACTIONS
	{
		DEFINITION
		{
			if (Loc_TempR_T_MbMe_Unit != 32)	
			{											
				TempR_P1_Option_Temperatur = 1;	// [degF]
			}											
			else 
			{											
				TempR_P1_Option_Temperatur = 0;	// [degC]
			}											
		}
	}
	VALIDITY	VALID_IF_TRUE (SENSOR_RTD_TEMP)
	HANDLING	READ & WRITE;	
}

VARIABLE	TempR_P1_Option_Stoerunterdrueckung
{
	LABEL		[P1_Option_Stoerunterdrueckung];
	HELP		[P1_Option_Stoerunterdrueckung_help];
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 0;
		{	0x0000,	[hz50]	},
		{	0x0001,	[hz60]	}
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	TempR_P1_Option_Bit4_15
{
	LABEL		[P0_DUMMY];
	HELP		[P0_DUMMY_help];
	TYPE		UNSIGNED_INTEGER (2);
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

/********** Skalierung *****************/

VARIABLE	TempR_P1_ScalMb
{
	LABEL		[P1_ScalMb];
	HELP		[P1_ScalMb_help];
	TYPE		UNSIGNED_INTEGER (2)
	{
		MIN_VALUE 0;
		MAX_VALUE 65535;
		DEFAULT_VALUE 10000;
	}
	CLASS		CONTAINED;
	POST_EDIT_ACTIONS
	{
		method_check_MbMe_int(TempR_P1_ScalMb, TempR_P1_ScalMe)
	}
	HANDLING	READ & WRITE;
}

VARIABLE	TempR_P1_ScalMe
{
	LABEL		[P1_ScalMe];
	HELP		[P1_ScalMe_help];
	TYPE		UNSIGNED_INTEGER (2)
	{
		MIN_VALUE 0;
		MAX_VALUE 65535;
		DEFAULT_VALUE 50000;
	}	
	CLASS		CONTAINED;
	POST_EDIT_ACTIONS
	{
		method_check_MbMe_int(TempR_P1_ScalMb, TempR_P1_ScalMe)
	}
	HANDLING	READ & WRITE;
}

VARIABLE	TempR_P1_ScalOption
{
	LABEL		[P1_ScalOption];
	HELP		[P1_ScalOption_help];
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 0;
		{	0x00,	[ohne_status]	},
		{	0x01,	[mit_status]	}
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	TempR_P1_LimLow
{
	LABEL		[P1_LimLow];
	HELP		[P1_LimLow_help];
	TYPE		UNSIGNED_INTEGER (2)
	{
		MIN_VALUE 0;
		MAX_VALUE 65535;
		DEFAULT_VALUE 0;
	}	
	CLASS		CONTAINED;
	POST_EDIT_ACTIONS
	{
		method_check_MbMe_int(TempR_P1_LimLow, TempR_P1_LimHigh)
	}
	HANDLING	READ & WRITE;
}

VARIABLE	TempR_P1_LimHigh
{
	LABEL		[P1_LimHigh];
	HELP		[P1_LimHigh_help];
	TYPE		UNSIGNED_INTEGER (2)
	{
		MIN_VALUE 0;
		MAX_VALUE 65535;
		DEFAULT_VALUE 60000;
	}
	CLASS		CONTAINED;
	POST_EDIT_ACTIONS
	{
		method_check_MbMe_int(TempR_P1_LimLow, TempR_P1_LimHigh)
	}
	HANDLING	READ & WRITE;
}

VARIABLE	TempR_P1_Filter
{
	LABEL		[P1_Filter];
	HELP		[P1_Filter_help];
	TYPE		UNSIGNED_INTEGER (2)
	{
		MIN_VALUE 0;
		MAX_VALUE 1000;
		DEFAULT_VALUE 0;
	}
	
	CONSTANT_UNIT	[Percent_Second];
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

//********** Erweitert *****************/

VARIABLE	TempR_P1_Mb
{
	LABEL		[P1_Mb];
	HELP		[P1_Mb_help];
	TYPE		INTEGER (4)
	{
		DEFAULT_VALUE	0;
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	Loc_TempR_TC_P1_Mb
{
	LABEL		[P1_Mb];
	HELP		[P1_Mb_help];
	TYPE		FLOAT
	{
		MIN_VALUE		TempR_MB_ME_MIN_VALUES;
		MAX_VALUE		TempR_MB_ME_MAX_VALUES;
		DEFAULT_VALUE	TempR_MB_ME_MIN_VALUES;
		DISPLAY_FORMAT ".3f";
	}
	CLASS		LOCAL;
	PRE_EDIT_ACTIONS
	{
		IF (SENSOR_RTD_TEMP && SENSOR_RTD_UNIT_C)
		{
			method_scale1000_temp_C (MODUL_5y01, TempR_P1_Mb, Loc_TempR_TC_P1_Mb)
		}
	}
	POST_EDIT_ACTIONS
	{
		IF (SENSOR_RTD_TEMP && SENSOR_RTD_UNIT_C)
		{
			method_rescale1000_temp_C (MODUL_5y01, TempR_P1_Mb, Loc_TempR_TC_P1_Mb),
			method_check_MbMe_float(Loc_TempR_TC_P1_Mb, Loc_TempR_TC_P1_Me)
		}
	}
	VALIDITY	VALID_IF_TRUE (SENSOR_RTD_TEMP && SENSOR_RTD_UNIT_C)
	HANDLING	READ & WRITE;
}

Loc_TempR_TF_P1_Mb		LIKE VARIABLE	Loc_TempR_TC_P1_Mb
{
	REDEFINE	PRE_EDIT_ACTIONS
	{
		IF (SENSOR_RTD_TEMP && SENSOR_RTD_UNIT_F)
		{
			method_scale1000_temp_F (MODUL_5y01, TempR_P1_Mb, Loc_TempR_TF_P1_Mb)
		}
	}
	REDEFINE	POST_EDIT_ACTIONS
	{
		IF (SENSOR_RTD_TEMP && SENSOR_RTD_UNIT_F)
		{
			method_rescale1000_temp_F (MODUL_5y01, TempR_P1_Mb, Loc_TempR_TF_P1_Mb),
			method_check_MbMe_float(Loc_TempR_TF_P1_Mb, Loc_TempR_TF_P1_Me)
		}
	}
	REDEFINE	VALIDITY	VALID_IF_TRUE (SENSOR_RTD_TEMP && SENSOR_RTD_UNIT_F)
}

Loc_TempR_R_P1_Mb		LIKE VARIABLE	Loc_TempR_TC_P1_Mb
{
	REDEFINE	PRE_EDIT_ACTIONS
	{
		IF SENSOR_RTD_R
		{
			method_scale1000_int_float (TempR_P1_Mb, Loc_TempR_R_P1_Mb)
		}
	}
	REDEFINE	POST_EDIT_ACTIONS
	{
		IF SENSOR_RTD_R
		{
			method_rescale1000_int_float (TempR_P1_Mb, Loc_TempR_R_P1_Mb),
			method_check_MbMe_float(Loc_TempR_R_P1_Mb, Loc_TempR_R_P1_Me)
		}
	}
	REDEFINE	VALIDITY	VALID_IF_TRUE (SENSOR_RTD_R)
}

VARIABLE	TempR_P1_Me
{
	LABEL		[P1_Me];
	HELP		[P1_Me_help];
	TYPE		INTEGER (4)
	{
		DEFAULT_VALUE	100000;
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	Loc_TempR_TC_P1_Me
{
	LABEL		[P1_Me];
	HELP		[P1_Me_help];
	TYPE		FLOAT
	{
		MIN_VALUE		TempR_MB_ME_MIN_VALUES;
		MAX_VALUE		TempR_MB_ME_MAX_VALUES;
		DEFAULT_VALUE	TempR_MB_ME_MAX_VALUES;
		DISPLAY_FORMAT ".3f";
	}
	CLASS		LOCAL;
	HANDLING	READ & WRITE;
	PRE_EDIT_ACTIONS
	{
		IF (SENSOR_RTD_TEMP && SENSOR_RTD_UNIT_C)
		{
			method_scale1000_temp_C (MODUL_5y01, TempR_P1_Me, Loc_TempR_TC_P1_Me)
		}
	}
	POST_EDIT_ACTIONS
	{
		IF (SENSOR_RTD_TEMP && SENSOR_RTD_UNIT_C)
		{
			method_rescale1000_temp_C (MODUL_5y01, TempR_P1_Me, Loc_TempR_TC_P1_Me),
			method_check_MbMe_float(Loc_TempR_TC_P1_Mb, Loc_TempR_TC_P1_Me)
		}
	}
	VALIDITY	VALID_IF_TRUE (SENSOR_RTD_TEMP && SENSOR_RTD_UNIT_C)
}

Loc_TempR_TF_P1_Me		LIKE VARIABLE	Loc_TempR_TC_P1_Me
{
	REDEFINE	PRE_EDIT_ACTIONS
	{
		IF (SENSOR_RTD_TEMP && SENSOR_RTD_UNIT_F)
		{
			method_scale1000_temp_F (MODUL_5y01, TempR_P1_Me, Loc_TempR_TF_P1_Me)
		}
	}
	REDEFINE	POST_EDIT_ACTIONS
	{
		IF (SENSOR_RTD_TEMP && SENSOR_RTD_UNIT_F)
		{
			method_rescale1000_temp_F (MODUL_5y01, TempR_P1_Me, Loc_TempR_TF_P1_Me),
			method_check_MbMe_float(Loc_TempR_TF_P1_Mb, Loc_TempR_TF_P1_Me)
		}
	}
	REDEFINE	VALIDITY	VALID_IF_TRUE (SENSOR_RTD_TEMP && SENSOR_RTD_UNIT_F)

}

Loc_TempR_R_P1_Me		LIKE VARIABLE	Loc_TempR_TC_P1_Me
{
	REDEFINE	PRE_EDIT_ACTIONS
	{
		IF SENSOR_RTD_R
		{
			method_scale1000_int_float (TempR_P1_Me, Loc_TempR_R_P1_Me)
		}
	}
	REDEFINE	POST_EDIT_ACTIONS
	{
		IF SENSOR_RTD_R
		{
			method_rescale1000_int_float (TempR_P1_Me, Loc_TempR_R_P1_Me),
			method_check_MbMe_float(Loc_TempR_R_P1_Mb, Loc_TempR_R_P1_Me)
		}
	}
	REDEFINE	VALIDITY	VALID_IF_TRUE (SENSOR_RTD_R)
}

VARIABLE	TempR_P1_R1
{
	LABEL		[P1_R1];
	HELP		[P1_R1_help];
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	CONSTANT_UNIT	[Ohm];
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	Loc_TempR_P1_R1
{
	LABEL		[P1_R1];
	HELP		[P1_R1_help];
	TYPE		FLOAT
		{
			MIN_VALUE 0.00;
			MAX_VALUE 50.00;
			DEFAULT_VALUE 0.00;
			DISPLAY_FORMAT ".2f";
		}
	CONSTANT_UNIT	[Ohm];
	CLASS			LOCAL;
	VALIDITY	VALID_IF_TRUE (TempR_P1_Mode == 0)
	PRE_EDIT_ACTIONS
	{
		method_scale100_int_float (TempR_P1_R1, Loc_TempR_P1_R1)
	}
	POST_EDIT_ACTIONS
	{
		method_rescale100_int_float (TempR_P1_R1, Loc_TempR_P1_R1)
	}
	HANDLING		READ & WRITE;
}

VARIABLE	TempR_P1_Pt1
{
	LABEL		[P1_FrqPt1];
	HELP		[P1_FrqPt1_help];
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 1;
		{ 1,	[off]				},
		{ 2,	[filter_aktiv1] 	},
		{ 3,	[filter_aktiv2] 	},
		{ 4,	[filter_aktiv3] 	},
		{ 5,	[filter_aktiv4]		}

	}
	CLASS		CONTAINED;
	VALIDITY	VALID_IF_TRUE (TempR_P1_Option_Leitung == 1)
	HANDLING	READ & WRITE;
}

VARIABLE	TempR_P1_Val
{
	LABEL		[P1_Val];
	HELP		[P1_Val_help];
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 3;
		{ 0,	"0"					},
		{ 1,	"0%" 				},
		{ 2,	"100%" 				},
		{ 3,	[letzten_wert1]		}

	}
	VALIDITY	VALID_IF_TRUE (TempR_P1_Option_Leitung == 1)
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	TempR_P1_Tim
{
	LABEL		[P1_Tim];
	HELP		[P1_Tim_help];
	TYPE		UNSIGNED_INTEGER (2)
	{
		MIN_VALUE 1;
		MAX_VALUE 250;
		DEFAULT_VALUE 10;
	}
	CLASS		CONTAINED;
	VALIDITY	VALID_IF_TRUE (TempR_P1_Option_Leitung == 1)
	HANDLING	READ & WRITE;
}

VARIABLE	TempR_P1_DUMMY2
{
	LABEL		[P0_DUMMY];
	HELP		[P0_DUMMY_help];
	TYPE		ASCII (32);
	CLASS		CONTAINED;
	HANDLING	READ;
}

/*******************************************************************************/
/*****	COMMAND				****************************************************/
/*******************************************************************************/

#define DOWNLOAD_TempR							\
			P0_Type,							\
			P0_Slot0,							\
			P0_Index0,							\
			P0_Tag,								\
			P0_Channel,							\
			P0_Sector,							\
			P0_Option,							\
/*			P0_Time,							\
*/			P0_Revision,						\
			P0_Size,							\
			P0_CfgMode,					\
			Mod4y5y_P1_Slot1,					\
			Mod4y5y_P1_Index1,					\
			Mod4y5y_P1_Tag,						\
			Mod4y5y_P1_State,					\
			Mod4y5y_P1_ErrMode,					\
			Mod4y5y_P1_SimVal,					\
			Mod4y5y_P1_SimState_Data,			\
			Mod4y5y_P1_SimOption,				\
			Mod4y5y_P1_ErrVal,					\
			Mod4y5y_P1_ErrState_Data,			\
			Mod4y5y_P1_ErrOption,				\
			TempR_P1_Slot2,						\
			TempR_P1_Index2,					\
			TempR_P1_Mode,						\
			TempR_P1_Option_Leitung,			\
			TempR_P1_Option_Sensortyp,			\
			TempR_P1_Option_Temperatur,			\
			TempR_P1_Option_Stoerunterdrueckung,\
			TempR_P1_ScalMb,					\
			TempR_P1_ScalMe,					\
			TempR_P1_ScalOption,				\
			TempR_P1_LimLow,					\
			TempR_P1_LimHigh, 					\
			TempR_P1_Filter,					\
			TempR_P1_Mb,						\
			TempR_P1_Me,						\
			TempR_P1_R1,						\
			TempR_P1_Pt1,						\
			TempR_P1_Val,						\
			TempR_P1_Tim


#define	UPLOAD_TempR		DOWNLOAD_TempR


COMMAND read_TempR_index2
{
	SLOT		Loc_P0_Slot0;
	INDEX		2;
	OPERATION	READ;
	TRANSACTION
	{
		REQUEST
		{			
		}
		REPLY
		{
			TempR_P1_Slot2,
			TempR_P1_Index2,
			TempR_P1_Mode,
			TempR_P1_Option_Bit4_15					<0xFFF0>,
			TempR_P1_Option_Stoerunterdrueckung		<0x0008>,
			TempR_P1_Option_Temperatur				<0x0004>,
			TempR_P1_Option_Sensortyp				<0x0002>,
			TempR_P1_Option_Leitung					<0x0001>,
			TempR_P1_ScalMb, 
			TempR_P1_ScalMe,
			Bit1_15									<0xFFFE>,
			TempR_P1_ScalOption						<0x0001>,
			TempR_P1_LimLow,
			TempR_P1_LimHigh,
			TempR_P1_Filter,
			TempR_P1_Mb,
			TempR_P1_Me,
			TempR_P1_R1,
			TempR_P1_Pt1,
			TempR_P1_Val,
			TempR_P1_Tim,
			TempR_P1_DUMMY2
		}
	}
}

COMMAND write_TempR_index2
{
	SLOT		Loc_P0_Slot0;
	INDEX		2;
	OPERATION	WRITE;
	TRANSACTION
	{
		REQUEST
		{
			TempR_P1_Slot2,
			TempR_P1_Index2,
			TempR_P1_Mode,
			TempR_P1_Option_Bit4_15					<0xFFF0>,
			TempR_P1_Option_Stoerunterdrueckung		<0x0008>,
			TempR_P1_Option_Temperatur				<0x0004>,
			TempR_P1_Option_Sensortyp				<0x0002>,
			TempR_P1_Option_Leitung					<0x0001>,
			TempR_P1_ScalMb, TempR_P1_ScalMe,
			Bit1_15									<0xFFFE>,
			TempR_P1_ScalOption						<0x0001>,
			TempR_P1_LimLow,
			TempR_P1_LimHigh,
			TempR_P1_Filter,
			TempR_P1_Mb,
			TempR_P1_Me,
			TempR_P1_R1,
			TempR_P1_Pt1,
			TempR_P1_Val,
			TempR_P1_Tim,
			0, 0, 0, 0, 0, 0, 0, 0,   0, 0, 0, 0, 0, 0, 0, 0,	 // TempR_P1_DUMMY2
			0, 0, 0, 0, 0, 0, 0, 0,   0, 0, 0, 0, 0, 0, 0, 0	 // TempR_P1_DUMMY2
		}
		REPLY
		{
		}
	}
}


/*******************************************************************************/
/*****	Table: Specialist  *****************************************************/
/*******************************************************************************/

MENU Tab_s_TempR_kanal1
{
	LABEL		[menu_kanal1];
	ACCESS		OFFLINE;
	ITEMS
	{
		Tab_s_TempR_ident_k1,
		Tab_s_TempR_input_k1
	}
}

MENU Tab_s_TempR_ident_k1
{
	LABEL		[menu_ident];
	ACCESS		OFFLINE;
	ITEMS
	{
		Mod4y5y_P1_Tag
	}
}

MENU Tab_s_TempR_input_k1
{
	LABEL		[menu_input];
	ACCESS		OFFLINE;
	ITEMS
	{
		Mod4y5y_P1_State,
		Mod4y5y_P1_ErrMode,
//		TempR_P1_Filter						(READ_ONLY),
//		TempR_P1_LimLow						(READ_ONLY),
//		TempR_P1_LimHigh					(READ_ONLY),
		TempR_P1_Filter,
		TempR_P1_LimLow,
		TempR_P1_LimHigh,
		Tab_s_TempR_input_simulation,
		Tab_s_TempR_input_ersatzwert,
		Tab_s_TempR_input_skal,
		Tab_s_TempR_input_lfd,
		Tab_s_TempR_input_messumformer
	}
}

MENU Tab_s_TempR_input_simulation
{
	LABEL		[simulation];
	ACCESS		OFFLINE;
	ITEMS
	{
		Loc_Mod4y5y_P1_SimVal,
		Mod4y5y_P1_SimOption,
		Mod4y5y_P1_SimState_Data
	}
	VALIDITY	VALID_IF_TRUE (Mod4y5y_P1_State == 1)
}

MENU Tab_s_TempR_input_ersatzwert
{
	LABEL		[ersatzwert];
	ACCESS		OFFLINE;
	ITEMS
	{
		Loc_Mod4y5y_P1_ErrVal,
		Mod4y5y_P1_ErrOption,
		Mod4y5y_P1_ErrState_Data			(READ_ONLY)
	}
	VALIDITY	VALID_IF_TRUE (Mod4y5y_P1_ErrMode == 1)
}

MENU Tab_s_TempR_input_skal
{
	LABEL		[skalierung_in_bit_0_65535];
	ACCESS		OFFLINE;
	ITEMS
	{
		TempR_P1_ScalOption,
		TempR_P1_ScalMb,
		TempR_P1_ScalMe,
	}
}

MENU Tab_s_TempR_input_lfd
{
	LABEL		[leitungsueberwachung];
	ACCESS		OFFLINE;
	ITEMS
	{
		TempR_P1_Option_Leitung,
		TempR_P1_Pt1,
		TempR_P1_Val,
		TempR_P1_Tim
	}
}

MENU Tab_s_TempR_input_messumformer
{
	LABEL		[messumformer];
	ACCESS		OFFLINE;
	ITEMS
	{
		TempR_P1_Option_Sensortyp,
		TempR_P1_Mode,
		Loc_TempR_P1_R1,
		TempR_P1_Option_Stoerunterdrueckung,
		Loc_TempR_T_MbMe_Unit,
		Loc_TempR_TC_P1_Mb,
		Loc_TempR_TC_P1_Me,
		Loc_TempR_TF_P1_Mb,
		Loc_TempR_TF_P1_Me,
		Loc_TempR_R_P1_Mb,
		Loc_TempR_R_P1_Me
	}
}


/*******************************************************************************/
/*****	Table: Maintenance  *****************************************************/
/*******************************************************************************/

MENU Tab_m_TempR_kanal1
{
	LABEL		[menu_kanal1];
	ACCESS		OFFLINE;
	ITEMS
	{
		Tab_m_TempR_ident_k1,
		Tab_m_TempR_input_k1
	}
}

MENU Tab_m_TempR_ident_k1
{
	LABEL		[menu_ident];
	ACCESS		OFFLINE;
	ITEMS
	{
		Mod4y5y_P1_Tag
	}
}

MENU Tab_m_TempR_input_k1
{
	LABEL		[menu_input];
	ACCESS		OFFLINE;
	ITEMS
	{
		Mod4y5y_P1_State					(READ_ONLY),
		Mod4y5y_P1_ErrMode					(READ_ONLY),
		TempR_P1_Filter						(READ_ONLY),
		TempR_P1_LimLow						(READ_ONLY),
		TempR_P1_LimHigh					(READ_ONLY),
		Tab_m_TempR_input_simulation,
		Tab_m_TempR_input_ersatzwert,
		Tab_m_TempR_input_skal,
		Tab_m_TempR_input_lfd,
		Tab_m_TempR_input_messumformer
	}
}

MENU Tab_m_TempR_input_simulation
{
	LABEL		[simulation];
	ACCESS		OFFLINE;
	ITEMS
	{
		Loc_Mod4y5y_P1_SimVal				(READ_ONLY),
		Mod4y5y_P1_SimOption				(READ_ONLY),
		Mod4y5y_P1_SimState_Data			(READ_ONLY)
	}
	VALIDITY	VALID_IF_TRUE (Mod4y5y_P1_State == 1)
}


MENU Tab_m_TempR_input_ersatzwert
{
	LABEL		[ersatzwert];
	ACCESS		OFFLINE;
	ITEMS
	{
		Loc_Mod4y5y_P1_ErrVal				(READ_ONLY),
		Mod4y5y_P1_ErrOption				(READ_ONLY),
		Mod4y5y_P1_ErrState_Data			(READ_ONLY)
	}
	VALIDITY	VALID_IF_TRUE (Mod4y5y_P1_ErrMode == 1)
}

MENU Tab_m_TempR_input_skal
{
	LABEL		[skalierung_in_bit_0_65535];
	ACCESS		OFFLINE;
	ITEMS
	{
		TempR_P1_ScalOption					(READ_ONLY),
		TempR_P1_ScalMb						(READ_ONLY),
		TempR_P1_ScalMe						(READ_ONLY)
	}
}

MENU Tab_m_TempR_input_lfd
{
	LABEL		[leitungsueberwachung];
	ACCESS		OFFLINE;
	ITEMS
	{
		TempR_P1_Option_Leitung				(READ_ONLY),
		TempR_P1_Pt1						(READ_ONLY),
		TempR_P1_Val						(READ_ONLY),
		TempR_P1_Tim						(READ_ONLY)
	}
}

MENU Tab_m_TempR_input_messumformer
{
	LABEL		[messumformer];
	ACCESS		OFFLINE;
	ITEMS
	{
		TempR_P1_Option_Sensortyp			(READ_ONLY),
		TempR_P1_Mode						(READ_ONLY),
		Loc_TempR_P1_R1						(READ_ONLY),
		TempR_P1_Option_Stoerunterdrueckung	(READ_ONLY),
		Loc_TempR_T_MbMe_Unit				(READ_ONLY),
		Loc_TempR_TC_P1_Mb					(READ_ONLY),
		Loc_TempR_TC_P1_Me					(READ_ONLY),
		Loc_TempR_TF_P1_Mb					(READ_ONLY),
		Loc_TempR_TF_P1_Me					(READ_ONLY),
		Loc_TempR_R_P1_Mb					(READ_ONLY),
		Loc_TempR_R_P1_Me					(READ_ONLY)
	}
}
